import type { AgentContext } from '@aries-framework/core';
import type { GetNymResponse } from '@hyperledger/indy-vdr-shared';
import { Logger } from '@aries-framework/core';
import { IndyVdrModuleConfig } from '../IndyVdrModuleConfig';
import { IndyVdrPool } from './IndyVdrPool';
export interface CachedDidResponse {
    nymResponse: {
        did: string;
        verkey: string;
    };
    indyNamespace: string;
}
export declare class IndyVdrPoolService {
    pools: IndyVdrPool[];
    private logger;
    private indyVdrModuleConfig;
    constructor(logger: Logger, indyVdrModuleConfig: IndyVdrModuleConfig);
    /**
     * Create connections to all ledger pools
     */
    connectToPools(): Promise<number[]>;
    /**
     * Get the most appropriate pool for the given did.
     * If the did is a qualified indy did, the pool will be determined based on the namespace.
     * If it is a legacy unqualified indy did, the pool will be determined based on the algorithm as described in this document:
     * https://docs.google.com/document/d/109C_eMsuZnTnYe2OAd02jAts1vC4axwEKIq7_4dnNVA/edit
     */
    getPoolForDid(agentContext: AgentContext, did: string): Promise<IndyVdrPool>;
    private getPoolForLegacyDid;
    private getSettledDidResponsesFromPools;
    /**
     * Get the most appropriate pool for the given indyNamespace
     */
    getPoolForNamespace(indyNamespace: string): IndyVdrPool;
    private getDidFromPool;
}
export interface PublicDidRequest {
    did: CachedDidResponse;
    pool: IndyVdrPool;
    response: GetNymResponse;
}
